Color mapping ressources 
====================================

A good place for building sequential color palettes
http://colorbrewer2.org

Up to 8% of men are color-blind to some extent `source <https://nei.nih.gov/health/color_blindness/facts_about/>`_. Use this page to test your color mappings. 
https://www.color-blindness.com/coblis-color-blindness-simulator

Motivation for using something other than rainbow.
https://journals.ametsoc.org/doi/full/10.1175/BAMS-D-13-00155.1

The same people now provide a HCL palette maker
http://hclwizard.org:64230/hclwizard/

Pick colors from a color wheel. There are plenty like this one on the web. 
https://www.sessions.edu/color-calculator/


